| .is_allNA | R Documentation |
This function tests if a passed object is entirely comprised
of NA values.
.is_allNA(x)
x |
The object to test if is entirely comprised of |
This function is exported in order to provide one of the default
tests for the %|||% function and is not really intended for
use outside of that context.
A boolean (TRUE or FALSE)
{
.is_allNA(c(NA,NA,"NA")) # Will return FALSE
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.