| .is_length_zero | R Documentation |
This function tests if a passed object is of length 0.
.is_length_zero(x)
x |
The object to test if is length(0) |
This function is exported in order to provide one of the default
tests for the %|||% function and is not really intended for
use outside of that context.
A boolean (TRUE or FALSE)
{
.is_allFalse(c(FALSE,FALSE,TRUE)) # Will return FALSE
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.